Module spec

Module spec 

Spec module for paimon.

All paimon specs types are defined here.

Structs

ArrayType
ArrayType for paimon.
BigIntType
BigIntType for paimon.
BinaryRow
An implementation of InternalRow backed by raw binary bytes.
BinaryType
BinaryType for paimon.
BooleanType
BooleanType for paimon.
CharType
CharType for paimon.
ColumnMove
Represents a requested column move in a struct.
CoreOptions
Typed accessors for common table options.
DataField
Data field for paimon table.
DataFileMeta
Metadata of a data file.
DataTypeFamily
An enumeration of Data type families for clustering {@link DataTypeRoot}s into categories.
DateType
DateType for paimon.
DecimalType
DecimalType for paimon.
DeletionVectorMeta
DoubleType
DoubleType for paimon.
FloatType
FloatType for paimon.
GlobalIndexMeta
Metadata for a global index entry within an index file.
Identifier
The same {@link Identifier} indicates that the {@link ManifestEntry} refers to the same data file.
IndexFileMeta
Metadata of index file.
IndexManifest
Index manifest file reader (entries describing index files per partition/bucket).
IndexManifestEntry
Manifest entry for index file.
IntType
IntType for paimon.
LocalZonedTimestampType
LocalZonedTimestampType for paimon.
Manifest
Manifest file reader and writer.
ManifestEntry
Entry of a manifest file, representing an addition / deletion of a data file. Impl Reference: https://github.com/apache/paimon/blob/release-0.8.2/paimon-core/src/main/java/org/apache/paimon/manifest/ManifestEntry.java
ManifestFileMeta
Metadata of a manifest file.
ManifestList
Manifest list file reader and writer.
MapType
MapType for paimon.
MultisetType
MultisetType for paimon.
PartitionStatistics
Partition-level statistics for snapshot commits.
PredicateBuilder
Builds Predicate nodes from field names and typed literals.
RowType
RowType for paimon.
Schema
Schema of a table (logical DDL schema).
SchemaBuilder
Builder for Schema.
SmallIntType
SmallIntType for paimon.
Snapshot
Snapshot for paimon.
TableSchema
The table schema for paimon table.
TimeType
TimeType for paimon.
TimestampType
TimestampType for paimon.
TinyIntType
TinyIntType for paimon.
VarBinaryType
VarBinaryType for paimon.
VarCharType
VarCharType for paimon.

Enums

ColumnMoveType
The type of move.
CommitKind
Type of changes in this snapshot.
DataType
Data type for paimon table.
Datum
A typed literal value for predicate comparison.
FileKind
Kind of a file. Impl Reference: https://github.com/apache/paimon/blob/release-0.8.2/paimon-core/src/main/java/org/apache/paimon/manifest/FileKind.java
Predicate
A filter predicate — a tree of conditions.
PredicateOperator
Predicate operators for leaf predicates.
SchemaChange
Schema change to table.

Constants

EMPTY_BINARY_ROW
MANIFEST_FILE_META_SCHEMA
Avro schema for ManifestFileMeta (used in manifest-list files).
PARTITION_OPTION
Option key for partition in table options (same as CoreOptions.PARTITION).
PRIMARY_KEY_OPTION
Option key for primary key in table options (same as CoreOptions.PRIMARY_KEY).
ROW_ID_FIELD_ID
ROW_ID_FIELD_NAME
SCAN_TIMESTAMP_MILLIS_OPTION
SCAN_VERSION_OPTION

Statics

EMPTY_SERIALIZED_ROW

Functions

datums_to_binary_row
Build a serialized BinaryRow from optional Datum values. Returns empty vec if all values are None.
escape_identifier
escape_single_quotes
extract_datum_from_arrow
Extract a Datum from an Arrow RecordBatch column at the given row index.
field_idx_to_partition_idx
Map table schema field indices to partition row indices.
from_avro_bytes
to_avro_bytes
Serialize records into Avro Object Container File bytes.