pub struct LocalZonedTimestampType { /* private fields */ }Expand description
LocalZonedTimestampType for paimon.
Data type of a timestamp WITH LOCAL time zone consisting of year-month-day hour:minute:second[.fractional] zone with up to nanosecond precision and values ranging from 0000-01-01 00:00:00.000000000 +14:59 to 9999-12-31 23:59:59.999999999 -14:59. Leap seconds (23:59:60 and 23:59:61) are not supported as the semantics are closer to a point in time than a wall-clock time.
Impl Reference: https://github.com/apache/paimon/blob/release-0.8.2/paimon-common/src/main/java/org/apache/paimon/types/TimestampType.java.
Implementations
Sourceimpl LocalZonedTimestampType
impl LocalZonedTimestampType
pub const MIN_PRECISION: u32 = TimestampType::MIN_PRECISION
pub const MAX_PRECISION: u32 = TimestampType::MAX_PRECISION
pub const DEFAULT_PRECISION: u32 = TimestampType::DEFAULT_PRECISION
pub fn new(precision: u32) -> Result<Self, Error>
pub fn with_nullable(nullable: bool, precision: u32) -> Result<Self, Error>
pub fn precision(&self) -> u32
pub fn family(&self) -> DataTypeFamily