pub struct CommitMessage {
pub partition: Vec<u8>,
pub bucket: i32,
pub new_files: Vec<DataFileMeta>,
pub check_from_snapshot: Option<i64>,
pub new_changelog_files: Vec<DataFileMeta>,
pub new_index_files: Vec<IndexFileMeta>,
pub deleted_index_files: Vec<IndexFileMeta>,
pub deleted_files: Vec<DataFileMeta>,
}Expand description
A commit message representing new files to be committed for a specific partition and bucket.
Reference: org.apache.paimon.table.sink.CommitMessage
Fields
partition: Vec<u8>Binary row bytes for the partition.
bucket: i32Bucket id.
new_files: Vec<DataFileMeta>New data files to be added.
check_from_snapshot: Option<i64>Snapshot id from which row-id/column conflicts should be checked.
new_changelog_files: Vec<DataFileMeta>New changelog files to be added.
new_index_files: Vec<IndexFileMeta>New index files to be added (used by dynamic bucket mode).
deleted_index_files: Vec<IndexFileMeta>Index files to be removed from the current index manifest.
deleted_files: Vec<DataFileMeta>Files to be deleted (copy-on-write rewrite: old files replaced by new_files).
Implementations
Sourceimpl CommitMessage
impl CommitMessage