pub struct TableWrite { /* private fields */ }Expand description
TableWrite writes Arrow RecordBatches to Paimon data files.
Each (partition, bucket) pair gets its own DataFileWriter held in a HashMap.
Batches are routed to the correct writer based on partition/bucket.
Call prepare_commit() to close all writers and collect
CommitMessages for use with TableCommit.
Reference: pypaimon BatchTableWrite
Implementations
Sourceimpl TableWrite
impl TableWrite
Sourcepub async fn write_arrow_batch(&mut self, batch: &RecordBatch) -> Result<()>
pub async fn write_arrow_batch(&mut self, batch: &RecordBatch) -> Result<()>
Write an Arrow RecordBatch. Rows are routed to the correct partition and bucket.
Sourcepub async fn write_arrow(&mut self, batches: &[RecordBatch]) -> Result<()>
pub async fn write_arrow(&mut self, batches: &[RecordBatch]) -> Result<()>
Write multiple Arrow RecordBatches.
Sourcepub async fn prepare_commit(&mut self) -> Result<Vec<CommitMessage>>
pub async fn prepare_commit(&mut self) -> Result<Vec<CommitMessage>>
Close all writers and collect CommitMessages for use with TableCommit. Writers are cleared after this call, allowing the TableWrite to be reused.