Spec module for paimon.
All paimon specs types are defined here.
Structs
- Array
Type - ArrayType for paimon.
- BigInt
Type - BigIntType for paimon.
- Binary
Row - An implementation of InternalRow backed by raw binary bytes.
- Binary
Type - BinaryType for paimon.
- Boolean
Type - BooleanType for paimon.
- Char
Type - CharType for paimon.
- Column
Move - Represents a requested column move in a struct.
- Core
Options - Typed accessors for common table options.
- Data
Field - Data field for paimon table.
- Data
File Meta - Metadata of a data file.
- Data
Type Family - An enumeration of Data type families for clustering {@link DataTypeRoot}s into categories.
- Date
Type - DateType for paimon.
- Decimal
Type - DecimalType for paimon.
- Deletion
Vector Meta - Double
Type - DoubleType for paimon.
- Float
Type - FloatType for paimon.
- Global
Index Meta - Metadata for a global index entry within an index file.
- Identifier
- The same {@link Identifier} indicates that the {@link ManifestEntry} refers to the same data file.
- Index
File Meta - Metadata of index file.
- Index
Manifest - Index manifest file reader (entries describing index files per partition/bucket).
- Index
Manifest Entry - Manifest entry for index file.
- IntType
- IntType for paimon.
- Local
Zoned Timestamp Type - LocalZonedTimestampType for paimon.
- Manifest
- Manifest file reader and writer.
- Manifest
Entry - Entry of a manifest file, representing an addition / deletion of a data file. Impl Reference: https://github.com/apache/paimon/blob/release-0.8.2/paimon-core/src/main/java/org/apache/paimon/manifest/ManifestEntry.java
- Manifest
File Meta - Metadata of a manifest file.
- Manifest
List - Manifest list file reader and writer.
- MapType
- MapType for paimon.
- Multiset
Type - MultisetType for paimon.
- Partition
Statistics - Partition-level statistics for snapshot commits.
- Predicate
Builder - Builds
Predicatenodes from field names and typed literals. - RowType
- RowType for paimon.
- Schema
- Schema of a table (logical DDL schema).
- Schema
Builder - Builder for
Schema. - Small
IntType - SmallIntType for paimon.
- Snapshot
- Snapshot for paimon.
- Table
Schema - The table schema for paimon table.
- Time
Type - TimeType for paimon.
- Timestamp
Type - TimestampType for paimon.
- Tiny
IntType - TinyIntType for paimon.
- VarBinary
Type - VarBinaryType for paimon.
- VarChar
Type - VarCharType for paimon.
Enums
- Column
Move Type - The type of move.
- Commit
Kind - Type of changes in this snapshot.
- Data
Type - Data type for paimon table.
- Datum
- A typed literal value for predicate comparison.
- File
Kind - Kind of a file. Impl Reference: https://github.com/apache/paimon/blob/release-0.8.2/paimon-core/src/main/java/org/apache/paimon/manifest/FileKind.java
- Predicate
- A filter predicate — a tree of conditions.
- Predicate
Operator - Predicate operators for leaf predicates.
- Schema
Change - Schema change to table.
Constants
- EMPTY_
BINARY_ ROW - MANIFEST_
FILE_ META_ SCHEMA - Avro schema for ManifestFileMeta (used in manifest-list files).
- PARTITION_
OPTION - Option key for partition in table options (same as CoreOptions.PARTITION).
- PRIMARY_
KEY_ OPTION - Option key for primary key in table options (same as CoreOptions.PRIMARY_KEY).
- ROW_
ID_ FIELD_ ID - ROW_
ID_ FIELD_ NAME - SCAN_
TIMESTAMP_ MILLIS_ OPTION - SCAN_
VERSION_ OPTION
Statics
Functions
- datums_
to_ binary_ row - Build a serialized BinaryRow from optional Datum values. Returns empty vec if all values are None.
- escape_
identifier - escape_
single_ quotes - extract_
datum_ from_ arrow - Extract a Datum from an Arrow RecordBatch column at the given row index.
- field_
idx_ to_ partition_ idx - Map table schema field indices to partition row indices.
- from_
avro_ bytes - to_
avro_ bytes - Serialize records into Avro Object Container File bytes.