pub struct TagManager { /* private fields */ }Expand description
Manager for tag files using unified FileIO.
Tags are named snapshots stored as JSON files at {table_path}/tag/tag-{name}.
The tag file format is identical to a Snapshot JSON file.
Reference: org.apache.paimon.utils.TagManager
Implementations
Sourceimpl TagManager
impl TagManager
pub fn new(file_io: FileIO, table_path: String) -> Self
Sourcepub fn tag_directory(&self) -> String
pub fn tag_directory(&self) -> String
Path to the tag directory (e.g. table_path/tag).
Sourcepub fn tag_path(&self, tag_name: &str) -> String
pub fn tag_path(&self, tag_name: &str) -> String
Path to the tag file for the given name (e.g. tag/tag-my_tag).
Sourcepub async fn tag_exists(&self, tag_name: &str) -> Result<bool>
pub async fn tag_exists(&self, tag_name: &str) -> Result<bool>
Check if a tag exists.